@@ -8,7 +8,7 @@ T = TypeVar("T")
 def partition(
     predicate: Callable[[T], object], iterable: Iterable[T]
 ) -> tuple[list[T], list[T]]:
-    """Partition a sequence in to two list from a given predicate. The first list will contain
+    """Partition a sequence into two list from a given predicate. The first list will contain
     the values where the predicate is False, the second list will contain the remaining values.
 
     Args:
@@ -21,7 +21,7 @@ def partition(
     """
 
     result: tuple[list[T], list[T]] = ([], [])
-    appends = (result[0].append, result[1].append)
+    appends = (result[1].append, result[0].append)
     for value in iterable:
-        appends[1 if predicate(value) else 0](value)
+        appends[not predicate(value)](value)
     return result
